Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/__init__.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/documents/__init__.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/__init__.py	(revision 14310)
@@ -2,7 +2,7 @@
 """
 # Make this a package.
-from ikobacustom.skeleton.documents.document import SkeletonDocument
+from ikobacustom.aaue.documents.document import AAUEDocument
 
 __all__ = [
-    'SkeletonDocument',
+    'AAUEDocument',
     ]
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/document.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/documents/document.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/document.py	(revision 14310)
@@ -24,30 +24,30 @@
 from waeup.ikoba.utils.helpers import attrs_to_fields
 from waeup.ikoba.documents.document import PublicDocumentBase
-from ikobacustom.skeleton.documents.interfaces import ISkeletonDocument
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.aaue.documents.interfaces import IAAUEDocument
+from ikobacustom.aaue.interfaces import MessageFactory as _
 
 
-class SkeletonDocument(PublicDocumentBase):
+class AAUEDocument(PublicDocumentBase):
     """This is a document.
     """
-    grok.implements(ISkeletonDocument)
-    grok.provides(ISkeletonDocument)
+    grok.implements(IAAUEDocument)
+    grok.provides(IAAUEDocument)
 
-    form_fields_interface = ISkeletonDocument
+    form_fields_interface = IAAUEDocument
 
-SkeletonDocument = attrs_to_fields(SkeletonDocument)
+AAUEDocument = attrs_to_fields(AAUEDocument)
 
 
-class SkeletonDocumentFactory(grok.GlobalUtility):
+class AAUEDocumentFactory(grok.GlobalUtility):
     """A factory for documents.
     """
     grok.implements(IFactory)
-    grok.name(u'waeup.SkeletonDocument')
+    grok.name(u'waeup.AAUEDocument')
     title = u"Create a new document.",
-    description = u"This factory instantiates new skeleton documents."
+    description = u"This factory instantiates new aaue documents."
 
     def __call__(self, *args, **kw):
-        return SkeletonDocument(*args, **kw)
+        return AAUEDocument(*args, **kw)
 
     def getInterfaces(self):
-        return implementedBy(SkeletonDocument)
+        return implementedBy(AAUEDocument)
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/tests/test_browser.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/documents/tests/test_browser.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/tests/test_browser.py	(revision 14310)
@@ -27,8 +27,8 @@
 from zope.interface.verify import verifyObject, verifyClass
 from waeup.ikoba.documents.tests.test_batching import DocumentImportExportSetup
-from ikobacustom.skeleton.documents.document import SkeletonDocument
-from ikobacustom.skeleton.documents.export import SkeletonDocumentExporter
-from ikobacustom.skeleton.documents.batching import SkeletonDocumentProcessor
-from ikobacustom.skeleton.testing import FunctionalLayer
+from ikobacustom.aaue.documents.document import AAUEDocument
+from ikobacustom.aaue.documents.export import AAUEDocumentExporter
+from ikobacustom.aaue.documents.batching import AAUEDocumentProcessor
+from ikobacustom.aaue.testing import FunctionalLayer
 
 
@@ -38,5 +38,5 @@
 
     def setup_for_export(self):
-        document = SkeletonDocument()
+        document = AAUEDocument()
         document.document_id = u'DOC1'
         document.title = u'My first document'
@@ -49,5 +49,5 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonDocumentExporter()
+        exporter = AAUEDocumentExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
@@ -55,9 +55,9 @@
             'class_name,description,document_id,history,state,title,'
             'users_with_local_roles\r\n'
-            'SkeletonDocument,,DOC1,'
+            'AAUEDocument,,DOC1,'
             '[u\'2014-12-21 23:27:15 WAT - Document created by system\'],'
             'created,My first document,[]\r\n')
         # We can import the same file.
-        processor = SkeletonDocumentProcessor()
+        processor = AAUEDocumentProcessor()
         result = processor.doImport(
             self.outfile,
@@ -79,5 +79,5 @@
         self.assertEqual(num_fail,0)
         # We can import the same file in update mode.
-        processor = SkeletonDocumentProcessor()
+        processor = AAUEDocumentProcessor()
         result = processor.doImport(
             self.outfile,
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/tests/test_document.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/documents/tests/test_document.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/tests/test_document.py	(revision 14310)
@@ -17,5 +17,5 @@
 ##
 """
-Tests for skeleton documents.
+Tests for aaue documents.
 """
 from zope.interface.verify import verifyClass, verifyObject
@@ -23,9 +23,9 @@
 from waeup.ikoba.documents.container import DocumentsContainer
 
-from ikobacustom.skeleton.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.skeleton.documents.document import SkeletonDocument
-from ikobacustom.skeleton.documents.interfaces import ISkeletonDocument
+from ikobacustom.aaue.testing import (FunctionalLayer, FunctionalTestCase)
+from ikobacustom.aaue.documents.document import AAUEDocument
+from ikobacustom.aaue.documents.interfaces import IAAUEDocument
 
-class SkeletonDocumentTestCase(FunctionalTestCase):
+class AAUEDocumentTestCase(FunctionalTestCase):
 
     layer = FunctionalLayer
@@ -35,15 +35,15 @@
         self.assertTrue(
             verifyClass(
-                ISkeletonDocument, SkeletonDocument)
+                IAAUEDocument, AAUEDocument)
             )
         self.assertTrue(
             verifyObject(
-                ISkeletonDocument, SkeletonDocument())
+                IAAUEDocument, AAUEDocument())
             )
         return
 
-    def test_addSkeletonDocument(self):
+    def test_addAAUEDocument(self):
         container = DocumentsContainer()
-        document = createObject(u'waeup.SkeletonDocument')
+        document = createObject(u'waeup.AAUEDocument')
         document.document_id = u'DOC1'
         container.addDocument(document)
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/utils.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/documents/utils.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/utils.py	(revision 14310)
@@ -19,8 +19,8 @@
 """
 from waeup.ikoba.documents.utils import DocumentsUtils
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.aaue.interfaces import MessageFactory as _
 
 
-class SkeletonDocumentsUtils(DocumentsUtils):
+class AAUEDocumentsUtils(DocumentsUtils):
     """A collection of methods subject to customization.
     """
@@ -30,5 +30,5 @@
         'HTMLDocument': _('HTML Document'),
         'RESTDocument': _('REST Document'),
-        'SkeletonDocument': _('Skeleton Document'),
+        'AAUEDocument': _('AAUE Document'),
         }
 

Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/batching.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/documents/batching.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/batching.py	(revision 14310)
@@ -16,20 +16,20 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Batch processing for skeleton documents.
 """
 import grok
 from waeup.ikoba.documents.batching import DocumentProcessorBase
-from ikobacustom.skeleton.documents.interfaces import ISkeletonDocument
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.aaue.documents.interfaces import IAAUEDocument
+from ikobacustom.aaue.interfaces import MessageFactory as _
 
 
-class SkeletonDocumentProcessor(DocumentProcessorBase):
-    """A batch processor for ISkeletonDocument objects.
+class AAUEDocumentProcessor(DocumentProcessorBase):
+    """A batch processor for IAAUEDocument objects.
     """
-    util_name = 'skeletondocumentprocessor'
+    util_name = 'aauedocumentprocessor'
     grok.name(util_name)
 
-    name = _('Skeleton Document Processor')
-    iface = ISkeletonDocument
+    name = _('AAUE Document Processor')
+    iface = IAAUEDocument
 
-    factory_name = 'waeup.SkeletonDocument'
+    factory_name = 'waeup.AAUEDocument'
@@ -16,20 +16,20 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Batch processing for skeleton documents.
+"""Batch processing for aaue documents.
 """
 import grok
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/export.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/documents/export.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/export.py	(revision 14310)
@@ -16,17 +16,17 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Exporters for skeleton documents.
 """
 import grok
 from waeup.ikoba.documents.export import DocumentExporterBase
-from ikobacustom.skeleton.documents.interfaces import ISkeletonDocument
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.aaue.documents.interfaces import IAAUEDocument
+from ikobacustom.aaue.interfaces import MessageFactory as _
 
 
-class SkeletonDocumentExporter(DocumentExporterBase):
+class AAUEDocumentExporter(DocumentExporterBase):
     """Exporter for documents.
     """
-    grok.name('skeletondocuments')
-    iface = ISkeletonDocument
-    class_name = 'SkeletonDocument'
-    title = _(u'Skeleton Documents')
+    grok.name('aauedocuments')
+    iface = IAAUEDocument
+    class_name = 'AAUEDocument'
+    title = _(u'AAUE Documents')
@@ -16,17 +16,17 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Exporters for skeleton documents.
+"""Exporters for aaue documents.
 """
 import grok
Index: main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/interfaces.py
===================================================================
--- main/ikobacustom.aaue/trunk/src/ikobacustom/skeleton/documents/interfaces.py	(revision 14309)
+++ main/ikobacustom.aaue/trunk/src/ikobacustom/aaue/documents/interfaces.py	(revision 14310)
@@ -17,9 +17,9 @@
 ##
 from waeup.ikoba.documents.interfaces import IPublicDocument
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.aaue.interfaces import MessageFactory as _
 
 
-class ISkeletonDocument(IPublicDocument):
-    """A representation of a skeleton document.
+class IAAUEDocument(IPublicDocument):
+    """A representation of a aaue document.
 
     """